@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 2001-2011 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 2001-2013 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -125,6 +125,17 @@ MALLOC_DECLARE(M_NVIDIA);
 
 #define NV_SUPPORT_LINUX_COMPAT
 
+/*
+ * Enable/Disable support for ACPI method (_DOD, _ROM, etc.) invocation
+ * from the core driver.
+ */
+
+#if __FreeBSD_version >= 900044
+#define NV_SUPPORT_ACPI
+#else
+#undef NV_SUPPORT_ACPI
+#endif
+
 /*
  * Enable/Disable support for ACPI Power Management.
  */
