@@ -399,6 +399,24 @@
 #define __NV_CHECK_PCI_CONFIG_SPACE  CheckPCIConfigSpace
 #define NV_REG_CHECK_PCI_CONFIG_SPACE NV_REG_STRING(__NV_CHECK_PCI_CONFIG_SPACE)
 
+/*
+ * Option: AssignGpus
+ *
+ * Description:
+ *
+ * This option accepts string of pci bus locations of GPUs, seperated by comma,
+ * that NVIDIA module should probe. GPU PCI bus location string should be in any
+ * of the below formats, with domain, bus and slot numbers in hex:
+ *   bus:slot
+ *   domain:bus:slot
+ *   domain:bus:slot.func
+ * By default, this option is not set. When this option is not set, all
+ * supported NVIDIA GPUs are assigned to the NVIDIA kernel module.
+ */
+
+#define __NV_ASSIGN_GPUS AssignGpus
+#define NV_REG_ASSIGN_GPUS NV_REG_STRING(__NV_ASSIGN_GPUS)
+
 /*
  * Option: EnablePCIeGen3
  *
@@ -466,6 +484,8 @@ NV_DEFINE_REG_STRING_ENTRY(__NV_REGISTRY_DWORDS, NULL);
 NV_DEFINE_REG_STRING_ENTRY(__NV_RM_MSG, NULL);
 #endif
 
+NV_DEFINE_REG_STRING_ENTRY(__NV_ASSIGN_GPUS, NULL);
+
 /*
  *----------------registry database definition----------------------
  */
