@@ -28,6 +28,15 @@
 /* most cards in a single system */
 #define NV_MAX_DEVICES 32
 
+typedef struct {
+    NvU32    domain;        /* PCI domain number */
+    NvU8     bus;           /* PCI bus number    */
+    NvU8     slot;          /* PCI slot number   */
+    NvU16    vendor_id;     /* PCI vendor ID     */
+    NvU16    device_id;     /* PCI device ID     */
+    NvBool   valid;         /* validation flag   */
+} nv_pci_info_t;
+
 /* NOTE: using an ioctl() number > 55 will overflow! */
 #define NV_IOCTL_MAGIC      'F'
 #define NV_IOCTL_BASE       200
@@ -80,18 +89,15 @@ typedef struct nv_ioctl_xfer
 
 typedef struct nv_ioctl_card_info
 {
-    NvU16    flags;               /* see below                   */
-    NvU32    domain;              /* PCI domain number           */
-    NvU8     bus;                 /* PCI bus number              */
-    NvU8     slot;                /* PCI slot number             */
-    NvU16    vendor_id;           /* PCI vendor ID               */
-    NvU16    device_id;           /* PCI device ID               */
-    NvU32    gpu_id;
-    NvU16    interrupt_line;
-    NvU64    reg_address    NV_ALIGN_BYTES(8);
-    NvU64    reg_size       NV_ALIGN_BYTES(8);
-    NvU64    fb_address     NV_ALIGN_BYTES(8);
-    NvU64    fb_size        NV_ALIGN_BYTES(8);
+    NvU16         flags;               /* see below                   */
+    nv_pci_info_t pci_info;            /* PCI config information      */
+    NvU32         gpu_id;
+    NvU16         interrupt_line;
+    NvU64         reg_address    NV_ALIGN_BYTES(8);
+    NvU64         reg_size       NV_ALIGN_BYTES(8);
+    NvU64         fb_address     NV_ALIGN_BYTES(8);
+    NvU64         fb_size        NV_ALIGN_BYTES(8);
+    NvU32         minor_number;
 } nv_ioctl_card_info_t;
 
 #define NV_IOCTL_CARD_INFO_BUS_TYPE_PCI            0x0001
@@ -283,11 +289,7 @@ typedef struct
     int    flags;
 
     /* PCI config info */
-    NvU32 domain;
-    NvU16 bus;
-    NvU16 slot;
-    NvU16 vendor_id;
-    NvU16 device_id;
+    nv_pci_info_t pci_info;
     NvU16 subsystem_id;
     NvU32 gpu_id;
     void *handle;
@@ -314,14 +316,18 @@ typedef struct
 
 } nv_state_t;
 
+// Forward define the gpu ops structures
+typedef struct gpuSession      *nvgpuSessionHandle_t;
+typedef struct gpuAddressSpace *nvgpuAddressSpaceHandle_t;
+typedef struct gpuChannel      *nvgpuChannelHandle_t;
+typedef struct gpuObject       *nvgpuObjectHandle_t;
+typedef struct gpuChannelInfo  *nvgpuChannelInfo_t;
+typedef struct gpuCaps *nvgpuCaps_t;
+
 typedef struct
 {
     /* PCI config info */
-    NvU32 domain;
-    NvU16 bus;
-    NvU16 slot;
-    NvU16 vendor_id;
-    NvU16 device_id;
+    nv_pci_info_t pci_info;
     void *handle;
     nv_aperture_t bar0;
     nv_aperture_t *regs;
@@ -576,6 +582,7 @@ RM_STATUS  NV_API_CALL  rm_power_management      (nv_stack_t *, nv_state_t *, Nv
 RM_STATUS  NV_API_CALL  rm_save_low_res_mode     (nv_stack_t *, nv_state_t *);
 RM_STATUS  NV_API_CALL  rm_get_vbios_version     (nv_stack_t *, nv_state_t *, NvU32 *, NvU32 *, NvU32 *, NvU32 *, NvU32 *);
 RM_STATUS  NV_API_CALL  rm_get_gpu_uuid          (nv_stack_t *, nv_state_t *, NvU8 **, NvU32 *);
+RM_STATUS  NV_API_CALL  rm_get_gpu_uuid_raw      (nv_stack_t *, nv_state_t *, NvU8 **, NvU32 *);
 void       NV_API_CALL  rm_free_unused_clients   (nv_stack_t *, nv_state_t *, void *);
 
 RM_STATUS  NV_API_CALL  rm_read_registry_dword   (nv_stack_t *, nv_state_t *, NvU8 *, NvU8 *, NvU32 *);
@@ -613,12 +620,26 @@ RM_STATUS  NV_API_CALL  rm_suspend_smu            (nv_stack_t *);
 RM_STATUS  NV_API_CALL  rm_resume_smu             (nv_stack_t *);
 
 void       NV_API_CALL  rm_disable_gpu_state_persistence    (nv_stack_t *sp, nv_state_t *);
-
 RM_STATUS  NV_API_CALL  rm_p2p_init_mapping       (nv_stack_t *, NvU64, NvU64 *, NvU64 *, NvU64 *, NvU64 *, NvU64, NvU64, NvU64, NvU64, void (*)(void *), void *);
 RM_STATUS  NV_API_CALL  rm_p2p_destroy_mapping    (nv_stack_t *, NvU64);
 RM_STATUS  NV_API_CALL  rm_p2p_get_pages          (nv_stack_t *, NvU64, NvU32, NvU64, NvU64, NvU64 **, NvU32 **, NvU32 **, NvU32 *, void *, void (*)(void *), void *);
 RM_STATUS  NV_API_CALL  rm_p2p_put_pages          (nv_stack_t *, NvU64, NvU32, NvU64, void *);
 
+RM_STATUS  NV_API_CALL  rm_gpu_ops_create_session (nv_stack_t *, nvgpuSessionHandle_t *);
+RM_STATUS  NV_API_CALL  rm_gpu_ops_destroy_session (nv_stack_t *, nvgpuSessionHandle_t);
+RM_STATUS  NV_API_CALL  rm_gpu_ops_address_space_create(nv_stack_t *, nvgpuSessionHandle_t, unsigned long long, unsigned long long, nvgpuAddressSpaceHandle_t *);
+RM_STATUS  NV_API_CALL  rm_gpu_ops_address_space_create_mirrored(nv_stack_t *, nvgpuSessionHandle_t, unsigned long long, unsigned long long, nvgpuAddressSpaceHandle_t *);
+RM_STATUS  NV_API_CALL  rm_gpu_ops_address_space_destroy(nv_stack_t *, nvgpuAddressSpaceHandle_t);
+RM_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_fb(nv_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *);
+RM_STATUS  NV_API_CALL  rm_gpu_ops_memory_alloc_sys(nv_stack_t *, nvgpuAddressSpaceHandle_t, NvLength, NvU64 *);
+RM_STATUS  NV_API_CALL  rm_gpu_ops_memory_cpu_map(nv_stack_t *, nvgpuAddressSpaceHandle_t, NvU64, NvLength, void **);
+RM_STATUS  NV_API_CALL  rm_gpu_ops_memory_cpu_ummap(nv_stack_t *, nvgpuAddressSpaceHandle_t, void*);
+RM_STATUS  NV_API_CALL  rm_gpu_ops_channel_allocate(nv_stack_t *, nvgpuAddressSpaceHandle_t, nvgpuChannelHandle_t *, nvgpuChannelInfo_t);
+RM_STATUS  NV_API_CALL  rm_gpu_ops_channel_destroy(nv_stack_t *, nvgpuChannelHandle_t);
+const char*  NV_API_CALL  rm_gpu_ops_channel_translate_error(nv_stack_t *, NvU32);
+RM_STATUS  NV_API_CALL  rm_gpu_ops_copy_engine_allocate(nv_stack_t *, nvgpuChannelHandle_t, NvU32, NvU32*, nvgpuObjectHandle_t *);
+RM_STATUS  NV_API_CALL rm_gpu_ops_memory_free(nv_stack_t *, nvgpuAddressSpaceHandle_t, NvU64);
+
 #endif /* NVWATCH */
 
 #endif /* NVRM */
