@@ -2,7 +2,7 @@
 #include "os-interface.h"
 #include "nv.h"
 
-void* NV_API_CALL nv_i2c_add_adapter(nv_state_t *nv, U032 port)
+void* NV_API_CALL nv_i2c_add_adapter(nv_state_t *nv, NvU32 port)
 {
     return FALSE;
 }
