@@ -20,10 +20,10 @@
 
 #if defined(NVCPU_X86)
 #include "machine/../linux/linux.h"
-#endif
-
-#if defined(NVCPU_X86_64)
+#include "machine/../linux/linux_proto.h"
+#elif defined(NVCPU_X86_64)
 #include "machine/../linux32/linux.h"
+#include "machine/../linux32/linux32_proto.h"
 #endif
 
 int linux_ioctl_nvidia(d_thread_t *, struct linux_ioctl_args *);
@@ -33,18 +33,19 @@ int linux_ioctl_nvidia(
     struct linux_ioctl_args *args
 )
 {
-    /*
-     * The range has already been checked, and the native NVIDIA ioctl()
-     * implementation will throw out any commands it does not recognize.
-     * There is no good reason why we should manually translate each and
-     * every one of the possible NVIDIA ioctl commands.
-     *
-     * Since the Linux driver uses the _IO macros to encode the required
-     * data, the native ioctl layer can determine the parameter size and
-     * copy the user data in/out correctly.
-     */
+    struct file *fp;
+    int error;
+    u_long cmd;
 
-    return (ioctl(td, (struct ioctl_args *) args));
+    if ((error = fget(td, args->fd, CAP_IOCTL, &fp)) != 0)
+        return error;
+
+    cmd = args->cmd;
+
+    error = fo_ioctl(fp, cmd, (caddr_t)args->arg, td->td_ucred, td);
+    fdrop(fp, td);
+
+    return error;
 }
 
 struct linux_ioctl_handler nvidia_handler = {
@@ -68,4 +69,3 @@ void nvidia_linux_exit(void)
     linux_ioctl_unregister_handler(&nvidia_handler);
 #endif
 }
-
