@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 2001-2002 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 2001-2013 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -33,14 +33,14 @@ int nvidia_attach(device_t dev)
     sc = device_get_softc(dev);
     nv = sc->nv_state;
 
-    nv->os_state         = sc;
-    nv->flags            = 0;
-    nv->domain           = pci_get_domain(dev);
-    nv->bus              = pci_get_bus(dev);
-    nv->slot             = pci_get_slot(dev);
-    nv->vendor_id        = pci_get_vendor(dev);
-    nv->device_id        = pci_get_device(dev);
-    nv->handle           = dev;
+    nv->os_state           = sc;
+    nv->flags              = 0;
+    nv->pci_info.domain    = pci_get_domain(dev);
+    nv->pci_info.bus       = pci_get_bus(dev);
+    nv->pci_info.slot      = pci_get_slot(dev);
+    nv->pci_info.vendor_id = pci_get_vendor(dev);
+    nv->pci_info.device_id = pci_get_device(dev);
+    nv->handle             = dev;
 
     for (i = 0; i < NV_GPU_NUM_BARS; i++) {
         if (sc->BAR_recs[i] != NULL) {
@@ -68,7 +68,8 @@ int nvidia_attach(device_t dev)
                 "NVRM: Supported NVIDIA GPU Products' in this release's README,\n"
                 "NVRM: available on the FreeBSD graphics driver download page at\n"
                 "NVRM: www.nvidia.com.\n",
-                nv->bus, nv->slot, nv->vendor_id, nv->device_id, NV_VERSION_STRING);
+                nv->pci_info.bus, nv->pci_info.slot, nv->pci_info.vendor_id, 
+                nv->pci_info.device_id, NV_VERSION_STRING);
         }
         return ENXIO;
     }
@@ -367,18 +368,19 @@ int nvidia_get_card_info(void *args, int size)
             continue;
         nv = sc->nv_state;
 
-        ci[i].flags          = NV_IOCTL_CARD_INFO_FLAG_PRESENT;
-        ci[i].domain         = nv->domain;
-        ci[i].bus            = nv->bus;
-        ci[i].slot           = nv->slot;
-        ci[i].vendor_id      = nv->vendor_id;
-        ci[i].device_id      = nv->device_id;
-        ci[i].gpu_id         = nv->gpu_id;
-        ci[i].interrupt_line = nv->interrupt_line;
-        ci[i].fb_address     = nv->fb->address;
-        ci[i].fb_size        = nv->fb->size;
-        ci[i].reg_address    = nv->regs->address;
-        ci[i].reg_size       = nv->regs->size;
+        ci[i].flags              = NV_IOCTL_CARD_INFO_FLAG_PRESENT;
+        ci[i].pci_info.domain    = nv->pci_info.domain;
+        ci[i].pci_info.bus       = nv->pci_info.bus;
+        ci[i].pci_info.slot      = nv->pci_info.slot;
+        ci[i].pci_info.vendor_id = nv->pci_info.vendor_id;
+        ci[i].pci_info.device_id = nv->pci_info.device_id;
+        ci[i].gpu_id             = nv->gpu_id;
+        ci[i].interrupt_line     = nv->interrupt_line;
+        ci[i].fb_address         = nv->fb->address;
+        ci[i].fb_size            = nv->fb->size;
+        ci[i].reg_address        = nv->regs->address;
+        ci[i].reg_size           = nv->regs->size;
+        ci[i].minor_number       = i;
     }
 
     return 0;
@@ -532,20 +534,16 @@ int nvidia_open_dev(
 
         if (nv->ud.size != 0) {
             sc->UD_sg_list = sglist_alloc(1, M_WAITOK);
-            if (!sc->UD_sg_list) {
-                status = RM_ERR_NO_FREE_MEM;
+            if (!sc->UD_sg_list)
                 goto failed;
-            }
 
             sglist_append_phys(sc->UD_sg_list, nv->ud.address, nv->ud.size);
 
             sc->UD_object = NV_VM_PAGER_ALLOCATE(OBJT_SG, sc->UD_sg_list,
                     nv->ud.size, (VM_PROT_READ | VM_PROT_WRITE),
                     0, NULL);
-            if (!sc->UD_object) {
-                status = RM_ERR_NO_FREE_MEM;
+            if (!sc->UD_object)
                 goto failed;
-            }
 
             VM_OBJECT_LOCK(sc->UD_object);
             vm_object_set_memattr(sc->UD_object, VM_MEMATTR_UNCACHEABLE);
@@ -566,7 +564,8 @@ failed:
         if (sc->UD_sg_list != NULL)
             NV_SGLIST_FREE(sc->UD_sg_list);
 
-        NV_SHUTDOWN_ADAPTER(sp, nv);
+        if (status != EIO)
+            NV_SHUTDOWN_ADAPTER(sp, nv);
 
         if (sc->timer_sp != NULL)
             NV_UMA_ZONE_FREE_STACK(sc->timer_sp);
@@ -1410,8 +1409,8 @@ void NV_API_CALL nv_set_dma_address_size(
 
 void* NV_API_CALL nv_get_adapter_state(
     NvU32 domain,
-    NvU16 bus,
-    NvU16 slot
+    NvU8  bus,
+    NvU8  slot
 )
 {
     unsigned int i;
@@ -1424,13 +1423,13 @@ void* NV_API_CALL nv_get_adapter_state(
             continue;
         nv = sc->nv_state;
 
-        if ((nv->domain == domain) &&
-                (nv->bus == bus) && (nv->slot == slot)) {
+        if ((nv->pci_info.domain == domain) &&
+            (nv->pci_info.bus == bus) && (nv->pci_info.slot == slot)) {
             return (void *) nv;
         }
     }
 
-    if (bus == 255 && slot == 255) {
+    if (NV_PCI_MATCH_CTL_DEVICE(domain, bus, slot)) {
         nv = &nvidia_ctl_state;
         return (void *) nv;
     }
@@ -1450,72 +1449,6 @@ void NV_API_CALL nv_verify_pci_config(
     nvidia_pci_check_config_space(sp, dev, check_the_bars, FALSE, FALSE);
 }
 
-void NV_API_CALL nv_acpi_methods_init(NvU32 *handlesPresent)
-{
-    *handlesPresent = 0;
-}
-
-void NV_API_CALL nv_acpi_methods_uninit(void)
-{
-    return;
-}
-
-RM_STATUS NV_API_CALL nv_acpi_method(
-    NvU32 acpi_method,
-    NvU32 function,
-    NvU32 subFunction,
-    void *inParams,
-    NvU16 inParamSize,
-    NvU32 *outStatus,
-    void  *outData,
-    NvU16 *outDataSize
-)
-{
-    return RM_ERR_NOT_SUPPORTED;
-}
-
-RM_STATUS NV_API_CALL nv_acpi_dsm_method(
-    nv_state_t *nv,
-    NvU8 *pAcpiDsmGuid,
-    NvU32 acpiDsmRev,
-    NvU32 acpiDsmSubFunction,
-    void  *pInParams,
-    NvU16 inParamSize,
-    NvU32 *outStatus,
-    void  *pOutData,
-    NvU16 *pSize
-)
-{
-    return RM_ERR_NOT_SUPPORTED;
-}
-
-RM_STATUS NV_API_CALL nv_acpi_ddc_method(
-    nv_state_t *nv,
-    void *pEdidBuffer,
-    NvU32 *pSize
-)
-{
-    return RM_ERR_NOT_SUPPORTED;
-}
-
-RM_STATUS NV_API_CALL nv_acpi_dod_method(
-    nv_state_t *nv,
-    NvU32      *pOutData,
-    NvU32      *pSize
-)
-{
-    return RM_ERR_NOT_SUPPORTED;
-}
-
-RM_STATUS NV_API_CALL nv_acpi_rom_method(
-    nv_state_t *nv,
-    NvU32 *pInData,
-    NvU32 *pOutData
-)
-{
-    return RM_ERR_NOT_SUPPORTED;
-}
-
 void* NV_API_CALL nv_get_smu_state(void)
 {
     return NULL;
@@ -1551,3 +1484,14 @@ RM_STATUS NV_API_CALL nv_log_error(
 {
     return RM_OK;
 }
+
+RM_STATUS NV_API_CALL nv_alloc_os_descriptor_handle(
+    nv_state_t *nv,
+    NvS32       fd,
+    void       *private,
+    NvU64       num_pages,
+    NvU32      *handle
+)
+{
+    return RM_ERR_NOT_SUPPORTED;
+}
