@@ -411,6 +411,8 @@ typedef NvUFXP32                                                   NvUFXP16_16;
 typedef NvUFXP32                                                   NvUFXP20_12;
 typedef NvUFXP32                                                    NvUFXP24_8;
 
+typedef NvU64                                                      NvUFXP48_16;
+
 /*!
  * Utility macros used in converting between signed integers and fixed-point
  * notation.
@@ -460,9 +462,9 @@ typedef NvUFXP32                                                    NvUFXP24_8;
  *
  * - _ROUNDED:
  *   For fixed-point -> integer we add rounding to integer values.
- *
- * Unsigned:
  */
+
+// 32-bit Unsigned FXP:
 #define NV_TYPES_U32_TO_UFXP_X_Y(x, y, integer)                               \
     ((NvUFXP##x##_##y) (((NvU32) (integer)) <<                                \
                         DRF_SHIFT(NV_TYPES_FXP_INTEGER((x), (y)))))
@@ -482,9 +484,27 @@ typedef NvUFXP32                                                    NvUFXP24_8;
         !!DRF_VAL(_TYPES, _FXP, _FRACTIONAL_MSB((x), (y)),                    \
             ((NvUFXP##x##_##y) (fxp))))
 
-/*!
- * Signed:
- */
+// 64-bit Unsigned FXP
+#define NV_TYPES_U64_TO_UFXP_X_Y(x, y, integer)                               \
+    ((NvUFXP##x##_##y) (((NvU64) (integer)) <<                                \
+                        DRF_SHIFT(NV_TYPES_FXP_INTEGER((x), (y)))))
+
+#define NV_TYPES_U64_TO_UFXP_X_Y_SCALED(x, y, integer, scale)                 \
+    ((NvUFXP##x##_##y) (((((NvU64) (integer)) <<                              \
+                             DRF_SHIFT(NV_TYPES_FXP_INTEGER((x), (y)))) +     \
+                         ((scale) / 2)) /                                     \
+                        (scale)))
+
+#define NV_TYPES_UFXP_X_Y_TO_U64(x, y, fxp)                                   \
+    ((NvU64) (DRF_VAL(_TYPES, _FXP, _INTEGER((x), (y)),                       \
+                    ((NvUFXP##x##_##y) (fxp)))))
+
+#define NV_TYPES_UFXP_X_Y_TO_U64_ROUNDED(x, y, fxp)                           \
+    (NV_TYPES_UFXP_X_Y_TO_U64(x, y, (fxp)) +                                  \
+        !!DRF_VAL(_TYPES, _FXP, _FRACTIONAL_MSB((x), (y)),                    \
+            ((NvUFXP##x##_##y) (fxp))))
+
+// 32-bit Signed FXP:
 #define NV_TYPES_S32_TO_SFXP_X_Y(x, y, integer)                               \
     ((NvSFXP##x##_##y) (((NvS32) (integer)) <<                                \
                         DRF_SHIFT(NV_TYPES_FXP_INTEGER((x), (y)))))
@@ -570,6 +590,21 @@ typedef NvUFXP32                                                    NvUFXP24_8;
     ((NvS32)(DRF_VAL(_TYPES, _SINGLE, _EXPONENT, single) -                     \
         NV_TYPES_SINGLE_EXPONENT_BIAS))
 
+/*!
+ * NvTemp - temperature data type introduced to avoid bugs in conversion between
+ * various existing notations.
+ */
+typedef NvSFXP24_8              NvTemp;
+/*!
+ * Macros for NvType <-> Celsius temperature conversion.
+ */
+#define NV_TYPES_CELSIUS_TO_NV_TEMP(cel)                                      \
+                                NV_TYPES_S32_TO_SFXP_X_Y(24,8,(cel))
+#define NV_TYPES_NV_TEMP_TO_CELSIUS_TRUNCED(nvt)                              \
+                                NV_TYPES_SFXP_X_Y_TO_S32(24,8,(nvt))
+#define NV_TYPES_NV_TEMP_TO_CELSIUS_ROUNDED(nvt)                              \
+                                NV_TYPES_SFXP_X_Y_TO_S32_ROUNDED(24,8,(nvt))
+
 #include "xapi-sdk.h"       /* XAPIGEN sdk macros for C */
 
 
