@@ -31,32 +31,65 @@ typedef NvU32 RM_STATUS;
   NVOS_STATUS_IN_RM_STATUS              0x80000000
 */
 
-/*
-    IMPORTANT: When comparing RM_STATUS_LEVEL(_S) against one of these
-    constants, it is important to use '<=' or '>' (rather than '<' or '>=').
-
-    For example. do:
-        if (RM_STATUS_LEVEL(status) <= RM_STATUS_LEVEL_WARN)
-
-    rather than:
-        if (RM_STATUS_LEVEL(status) < RM_STATUS_LEVEL_ERR)
-
-    By being consistent in this manner, it is easier to systematically add
-    additional level constants.  New levels are likely to lower (rather
-    than raise) the severity of _ERR codes.  For example, if we were to add
-    RM_STATUS_LEVEL_RETRY to indicate hardware failures that may be recoverable
-    (e.g. RM_ERR_TIMEOUT_RETRY or RM_ERR_BUSY_RETRY), it would be less severe
-    than RM_STATUS_LEVEL_ERR the level to which these status codes now
-    belong.  Using '<=' and '>' ensures your code is not broken in this case.
-*/
+/*!
+ * @def         RM_STATUS_LEVEL_OK
+ * @see         RM_STATUS_LEVEL
+ * @brief       Success: No error or special condition
+ */
 #define RM_STATUS_LEVEL_OK              0
+
+/*!
+ * @def         RM_STATUS_LEVEL_WARN
+ * @see         RM_STATUS_LEVEL
+ * @brief       Sucess, but there is an special condition
+ *
+ * @details     In general, RM_STATUS_LEVEL_WARN status codes are handled the
+ *              same as RM_STATUS_LEVEL_OK, but are usefil to indicate that
+ *              there is a condition that may be specially handled.
+ *
+ *              Therefore, in most cases, client function should test for
+ *              status <= RM_STATUS_LEVEL_WARN or status > RM_STATUS_LEVEL_WARN
+ *              to determine success v. failure of a call.
+ */
 #define RM_STATUS_LEVEL_WARN            1
+
+/*!
+ * @def         RM_STATUS_LEVEL_ERR
+ * @see         RM_STATUS_LEVEL
+ * @brief       Unrecoverable error condition
+ */
 #define RM_STATUS_LEVEL_ERR             3
+
+/*!
+ * @def         RM_STATUS_LEVEL
+ * @see         RM_STATUS_LEVEL_OK
+ * @see         RM_STATUS_LEVEL_WARN
+ * @see         RM_STATUS_LEVEL_ERR
+ * @brief       Level of the status code
+ *
+ * @warning     IMPORTANT: When comparing RM_STATUS_LEVEL(_S) against one of
+ *              these constants, it is important to use '<=' or '>' (rather
+ *              than '<' or '>=').
+ *
+ *              For example. do:
+ *                  if (RM_STATUS_LEVEL(status) <= RM_STATUS_LEVEL_WARN)
+ *              rather than:
+ *                  if (RM_STATUS_LEVEL(status) < RM_STATUS_LEVEL_ERR)
+ *
+ *              By being consistent in this manner, it is easier to systematically
+ *              add additional level constants.  New levels are likely to lower
+ *              (rather than raise) the severity of _ERR codes.  For example,
+ *              if we were to add RM_STATUS_LEVEL_RETRY to indicate hardware
+ *              failures that may be recoverable (e.g. RM_ERR_TIMEOUT_RETRY
+ *              or RM_ERR_BUSY_RETRY), it would be less severe than
+ *              RM_STATUS_LEVEL_ERR the level to which these status codes now
+ *              belong.  Using '<=' and '>' ensures your code is not broken in
+ *              cases like this.
+ */
 #define RM_STATUS_LEVEL(_S)                                             \
     ((_S) == RM_OK?                             RM_STATUS_LEVEL_OK:     \
-    ((_S) == RM_ERR_MORE_PROCESSING_REQUIRED?   RM_STATUS_LEVEL_WARN:   \
     ((_S) != RM_ERROR && (_S) & 0x00000100?     RM_STATUS_LEVEL_WARN:   \
-                                                RM_STATUS_LEVEL_ERR)))
+                                                RM_STATUS_LEVEL_ERR))
 
 
 #define RM_ERR_CANT_CREATE_CLASS_OBJS   0x00000001
@@ -120,7 +153,6 @@ typedef NvU32 RM_STATUS;
 #define RM_ERR_I2C_ERROR                0x0000003B
 #define RM_ERR_FREQ_NOT_SUPPORTED       0x0000003C
 #define RM_ERR_INVALID_REQUEST          0x0000003D
-#define RM_ERR_MORE_PROCESSING_REQUIRED 0x0000003E      // warning in most cases
 #define RM_ERR_MISSING_TABLE_ENTRY      0x0000003F
 #define RM_ERR_NO_INTR_PENDING          0x00000040
 #define RM_ERR_INSUFFICIENT_PERMISSIONS 0x00000041
@@ -137,9 +169,8 @@ typedef NvU32 RM_STATUS;
 #define RM_ERR_I2C_SPEED_TOO_HIGH       0x00000050
 #define RM_ERR_INVALID_IRQ_LEVEL        0x00000051
 #define RM_ERR_BUSY_RETRY               0x00000052
-
 #define RM_ERR_INVALID_PATH             0x00000060
-#define RM_ERR_CANT_HOT_SWITCH          0x00000061
+#define RM_ERR_HOT_SWITCH               0x00000061
 #define RM_ERR_MISMATCHED_TARGET        0x00000062
 #define RM_ERR_OUT_OF_RANGE             0x00000063
 #define RM_ERR_NO_VALID_PATH            0x00000064
@@ -148,8 +179,12 @@ typedef NvU32 RM_STATUS;
 #define RM_ERR_RESET_REQUIRED           0x00000067
 
 // Warnings:
-#define RM_WARN_NULL_OBJECT             0x00000100
-#define RM_WARN_INCORRECT_PERFMON_DATA  0x00000101
-#define RM_WARN_NOTHING_TO_DO           0x00000102
+#define RM_WARN_NULL_OBJECT                 0x00000100
+#define RM_WARN_INCORRECT_PERFMON_DATA      0x00000101
+#define RM_WARN_NOTHING_TO_DO               0x00000102
+#define RM_WARN_MORE_PROCESSING_REQUIRED    0x0000013E
+#define RM_WARN_HOT_SWITCH                  0x00000161
+#define RM_WARN_MISMATCHED_TARGET           0x00000162
+#define RM_WARN_OUT_OF_RANGE                0x00000163
 
 #endif /* _RMRETVAL_H_ */
